| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
NanoVG.Internal.State
Documentation
Pushes and saves the current render state into a state stack.
A matching restore must be used to restore the state.
Resets current render state to default values. Does not affect the render state stack.